@@ -26,7 +26,7 @@ class VegaRenderer(Renderer):
 
     SCRIPTS = """
     <script src="https://cdn.jsdelivr.net/npm/vega@5.20.2"></script>
-    <script src="https://cdn.jsdelivr.net/npm/vega-lite@5.1.0"></script>
+    <script src="https://cdn.jsdelivr.net/npm/vega-lite@5.2.0"></script>
     <script src="https://cdn.jsdelivr.net/npm/vega-embed@6.18.2"></script>
     """
 
@@ -83,5 +83,5 @@ class VegaRenderer(Renderer):
 
         return content
 
-    def partial_html(self) -> str:
+    def partial_html(self, **kwargs) -> str:
         return self.get_filled_template()
